##############################################################################
#
# MODULE:       r.randomwalk.install.sh
#
# AUTHOR:       Martin Mergili
#
# PURPOSE:      Conceptual tool for mass movement propagation
#               Installation script
#
# COPYRIGHT:    (c) 2010 - 2015 by the author
#               (c) 2010 - 2015 by the BOKU University, Vienna
#               (c) 2015        by the University of Vienna
#               (c) 2000 - 2015 by the GRASS Development Team
#
# VERSION:      20151016 (16 October 2015)
#
#               This program is free software under the GNU General Public
#               License (>=v2). Read the file COPYING that comes with GRASS
#               for details.
#
##############################################################################


pathmain=`pwd`

#PATHSOURCE="/usr/local/src/releasebranch_7_0/"
#PATHGRASS="/usr/local/grass-7.0.2svn/"
#PATHPYTHON="/usr/lib/python2.7/"

echo "Full path to GRASS source (slashes at beginning and end): "
read PATHSOURCE

echo "Full path to GRASS installation (slashes at beginning and end): "
read PATHGRASS

echo "Full path to Python installation (slashes at beginning and end): "
read PATHPYTHON


#INSTALLING R- AND PYTHON-BASED MODULES FOR DATA MANAGEMENT
#Exporting parameters
export GISBASE="$PATHGRASS"
export PATH="$PATH:$GISBASE/bin:$GISBASE/scripts"
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$GISBASE/lib"
export GIS_LOCK=$$
export GISRC="$HOME/.grassrc6"
export PYTHONPATH="$PYTHONPATH:$GISBASE/etc/python"

#Installing R scripts
cp r.randomwalk.cdf.r "$PATHGRASS"scripts/r.randomwalk.cdf.r
cp r.randomwalk.map.r "$PATHGRASS"scripts/r.randomwalk.map.r
cp r.randomwalk.roc.r "$PATHGRASS"scripts/r.randomwalk.roc.r

#r.randomwalk.py is installed as a module r.randomwalk
#Making python script executable
chmod +x r.randomwalk.py

#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"scripts/r.randomwalk ]
then
    rm -rf "$PATHSOURCE"scripts/r.randomwalk
fi

#Creating directory for installation files, copying r.randomwalk.py and r.randomwalk.html
mkdir "$PATHSOURCE"scripts/r.randomwalk
cp r.randomwalk.py "$PATHSOURCE"scripts/r.randomwalk/r.randomwalk.py
cp r.randomwalk.html "$PATHSOURCE"scripts/r.randomwalk/r.randomwalk.html

#Moving to the directory for installation files
cd "$PATHSOURCE"scripts/r.randomwalk

# Creating help file and makefile
touch r.randomwalk.html
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.randomwalk" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Script.make" >> Makefile
echo "" >> Makefile
echo "default: script" >> Makefile

#Installing r.randomwalk
make
make install

cd $pathmain

#r.randomwalk.mult.py is installed as module r.randomwalk.mult
#Making python script executable
chmod +x r.randomwalk.mult.py

#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"scripts/r.randomwalk.mult ]
then
    rm -rf "$PATHSOURCE"scripts/r.randomwalk.mult
fi

#Creating directory for installation files, copying r.randomwalk.mult.py
mkdir "$PATHSOURCE"scripts/r.randomwalk.mult
cp r.randomwalk.mult.py "$PATHSOURCE"scripts/r.randomwalk.mult/r.randomwalk.mult.py
cp r.randomwalk.html "$PATHSOURCE"scripts/r.randomwalk.mult/r.randomwalk.mult.html

#Moving to the directory for installation files
cd "$PATHSOURCE"scripts/r.randomwalk.mult

# Creating help file and makefile
touch r.randomwalk.mult.html
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.randomwalk.mult" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Script.make" >> Makefile
echo "" >> Makefile
echo "default: script" >> Makefile

#Installing r.randomwalk.mult
make
make install

echo ""
echo "Installation of r.randomwalk, r.randomwalk.mult and associated scripts completed. Please check for possible error messages. "
echo "Press ENTER for proceeding with the installation of r.randomwalk.main. "
read answer

#Returning to initial directory
cd $pathmain
clear


#INSTALLING C-BASED MODULE FOR FLOW ROUTING
#r.randomwalk.main.c is installed as module r.randomwalk.main
#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"raster/r.randomwalk.main ]
then
    rm -rf "$PATHSOURCE"raster/r.randomwalk.main
fi

#Creating directory for installation files and copying r.randomwalk.main.c
mkdir "$PATHSOURCE"raster/r.randomwalk.main
cp r.randomwalk.main.c "$PATHSOURCE"raster/r.randomwalk.main/main.c
cp r.randomwalk.html "$PATHSOURCE"dist.x86_64-unknown-linux-gnu/docs/html/r.randomwalk.main.html

#Moving to the directory for installation files
cd "$PATHSOURCE"raster/r.randomwalk.main

# Creating makefile
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.randomwalk.main" >> Makefile
echo "" >> Makefile
echo "LIBES = \$(GPROJDEP) \$(GISLIB) \$(SEGMENTLIB) \$(RASTERLIB) \$(GMATHLIB)" >> Makefile
echo "DEPENDENCIES = \$(GPROJDEP) \$(GISDEP) \$(GMATHDEP)" >> Makefile
echo "EXTRA_INC = \$(PROJINC)" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Module.make" >> Makefile
echo "" >> Makefile
echo "default: cmd" >> Makefile

# Installing r.randomwalk.main
make
make install

echo ""
echo "Installation of r.randomwalk.main completed. Please check for possible error messages. "
echo "Press ENTER for exit. "
read answer

#Returning to initial directory and terminating sudo mode
cd $pathmain
sudo -k
clear

